from typing import Optional
from datetime import datetime
from pydantic import BaseModel


# Shared properties
class TodoBase(BaseModel):
    title: str
    description: Optional[str] = None
    completed: bool = False


# Properties to receive on todo creation
class TodoCreate(TodoBase):
    pass


# Properties to receive on todo update
class TodoUpdate(TodoBase):
    title: Optional[str] = None
    completed: Optional[bool] = None


# Properties shared by models stored in DB
class TodoInDBBase(TodoBase):
    id: int
    created_at: datetime
    updated_at: Optional[datetime] = None

    class Config:
        orm_mode = True


# Properties to return to client
class Todo(TodoInDBBase):
    pass